type Control = {
    pause: () => void;
    continue: () => void;
    reset: () => void;
};
/**
 * - ✅ Handling **global** and **external** services (_preparing a database, for example_)
 * - ✅ It's made for **exclusive use** in combination with **Poku**'s **`assert`** methods
 * - ❌ Changing local variables values and states ([_use a mock instead_](https://poku.dev/docs/category/mock))
 *
 * ---
 *
 * ### Available methos:
 *
 * ```ts
 * import { assert, beforeEach } from 'poku';
 *
 * const before = beforeEach(() => {
 *   // preparing an external or global state
 * };
 *
 * before.pause();
 * before.continue();
 * before.reset();
 * ```
 */
export declare const beforeEach: (callback: () => unknown) => Control;
/**
 * - ✅ Handling **global** and **external** services (_preparing a database, for example_)
 * - ✅ It's made for **exclusive use** in combination with **Poku**'s **`assert`** methods
 * - ❌ Changing local variables values and states ([_use a mock instead_](https://poku.dev/docs/category/mock))
 *
 * ---
 *
 * ### Available methos:
 *
 * ```ts
 * import { assert, afterEach } from 'poku';
 *
 * const after = afterEach(() => {
 *   // cleanup an external or global state
 * };
 *
 * after.pause();
 * after.continue();
 * after.reset();
 * ```
 */
export declare const afterEach: (callback: () => unknown) => Control;
export {};
